@@ -107,15 +107,20 @@ def check_access_rights(service: str,
                 if not auth_enabled:
                     authorized_clients = [ALL_CLIENTS_RIGHTS]
                 else:
+                    # Value defined for service to service calls
+                    service_authorized_clients = claims.get('authorized_clients')
                     db_user_id = claims.get('db_user_id')
-                    if not db_user_id:
-                        authorized_clients = []
+                    if service_authorized_clients and not db_user_id:
+                        authorized_clients = service_authorized_clients
                     else:
-                        user = datastore_client.get_entity(USERS_KIND, int(db_user_id))
-                        if user is None:
+                        if not db_user_id:
                             authorized_clients = []
                         else:
-                            authorized_clients = user.get('authorized_clients', [])
+                            user = datastore_client.get_entity(USERS_KIND, int(db_user_id))
+                            if user is None:
+                                authorized_clients = []
+                            else:
+                                authorized_clients = user.get('authorized_clients', [])
 
                 if ALL_CLIENTS_RIGHTS in authorized_clients:
                     authorized_clients.remove(ALL_CLIENTS_RIGHTS)
