@@ -8,13 +8,11 @@ class ServiceEnum:
     DATALAB = 'datalab_monitoring'
     DEVICE_OPTIMISATION = 'device_optimisation'
     FEED_DRIVEN_ADS = 'feed_driven_ads'
-    FEED_DRIVEN_UPDATES = 'feed_driven_update'
     LAB = 'lab'
     NOTIFICATIONS = 'notification'
     MCT_ALERTS = 'alerts_mct'
     PERFORMANCE_MONITORING = 'performance_monitoring'
     PILOT = 'pilot_dashboard'
-    SANITY_CHECK = 'sanity_check'
     SEARCH_TERMS = 'search_term'
     SMART_FEEDS_ING = 'smart_feeds_ingestions'
     SMART_FEEDS_PROC = 'smart_feeds_processings'
